AdPlayer class abstract

Constructors

AdPlayer()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getTagWhenReady({required String tagId}) Future<String>
getVersion() Future<String>
initialize({String? iosStoreUrl}) Future<void>
initializePublisher({required String publisherId, required String tagId}) Future<void>
reportLayoutChange() Future<void>