MethodChannelAdPlayerFlutterPlugin class
An implementation of AdPlayerFlutterPluginPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- AdPlayerFlutterPluginPlatform
- MethodChannelAdPlayerFlutterPlugin
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAdPlayerVersion(
) → Future< String?> -
override
-
initAdPlayerSdk(
String publisherId, String tagId) → Future< void> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reportLayoutChange(
) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited